pub trait AnyError: Any + Error { }Expand description
Types that represent errors that can happen during reduction.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait AnyError: Any + Error { }Types that represent errors that can happen during reduction.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".